@@ -2,8 +2,28 @@
 /* Generated data (by glib-mkenums) */
 
 #include "gdict-enum-types.h"
-/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-context.h" */
-#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-context.h"
+/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-client-context.h" */
+#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-client-context.h"
+GType
+gdict_client_context_error_get_type (void)
+{
+  static GType g_enum_type_id = 0;
+  if (G_UNLIKELY (g_enum_type_id == 0))
+    {
+      static const GEnumValue values[] = {
+        { GDICT_CLIENT_CONTEXT_ERROR_SOCKET, "GDICT_CLIENT_CONTEXT_ERROR_SOCKET", "socket" },
+        { GDICT_CLIENT_CONTEXT_ERROR_LOOKUP, "GDICT_CLIENT_CONTEXT_ERROR_LOOKUP", "lookup" },
+        { GDICT_CLIENT_CONTEXT_ERROR_NO_CONNECTION, "GDICT_CLIENT_CONTEXT_ERROR_NO_CONNECTION", "no-connection" },
+        { GDICT_CLIENT_CONTEXT_ERROR_SERVER_DOWN, "GDICT_CLIENT_CONTEXT_ERROR_SERVER_DOWN", "server-down" },
+        { 0, NULL, NULL }
+      };
+      g_enum_type_id = g_enum_register_static("GdictClientContextError", values);
+    }
+
+  return g_enum_type_id;
+}
+/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-context.h" */
+#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-context.h"
 GType
 gdict_context_error_get_type (void)
 {
@@ -26,28 +46,8 @@ gdict_context_error_get_type (void)
 
   return g_enum_type_id;
 }
-/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-client-context.h" */
-#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-client-context.h"
-GType
-gdict_client_context_error_get_type (void)
-{
-  static GType g_enum_type_id = 0;
-  if (G_UNLIKELY (g_enum_type_id == 0))
-    {
-      static const GEnumValue values[] = {
-        { GDICT_CLIENT_CONTEXT_ERROR_SOCKET, "GDICT_CLIENT_CONTEXT_ERROR_SOCKET", "socket" },
-        { GDICT_CLIENT_CONTEXT_ERROR_LOOKUP, "GDICT_CLIENT_CONTEXT_ERROR_LOOKUP", "lookup" },
-        { GDICT_CLIENT_CONTEXT_ERROR_NO_CONNECTION, "GDICT_CLIENT_CONTEXT_ERROR_NO_CONNECTION", "no-connection" },
-        { GDICT_CLIENT_CONTEXT_ERROR_SERVER_DOWN, "GDICT_CLIENT_CONTEXT_ERROR_SERVER_DOWN", "server-down" },
-        { 0, NULL, NULL }
-      };
-      g_enum_type_id = g_enum_register_static("GdictClientContextError", values);
-    }
-
-  return g_enum_type_id;
-}
-/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-source.h" */
-#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-source.h"
+/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-source.h" */
+#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-source.h"
 GType
 gdict_source_transport_get_type (void)
 {
@@ -82,8 +82,8 @@ gdict_source_error_get_type (void)
 
   return g_enum_type_id;
 }
-/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-utils.h" */
-#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.18.0-1.i686/src/gnome-dictionary-3.18.0/libgdict/gdict-utils.h"
+/* enumerations from "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-utils.h" */
+#include "/usr/src/ports/gnome-dictionary/gnome-dictionary-3.24.0-1.x86_64/src/gnome-dictionary-3.24.0/libgdict/gdict-utils.h"
 GType
 gdict_context_prop_get_type (void)
 {
